==> owncloud-app-contacts-2%3A1.3.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/es.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "Address book name" : "Nombre de libreta de direcciones",
    "Import" : "Importar",
    "The selected image is too big (max 1MB)" : "La imagen seleccionada es demasiada grande (máximo 1MB)",
    "No contacts in here" : "No hay contactos aquí",
    "Name" : "Nombre",
    "Organization" : "Organización",
    "Title" : "Título",
    "Add field ..." : "Añadiendo campo ...",
    "Add contact" : "Añadir contacto",
    "No search result for {query}" : "Sin resultados para {query}",
    "All contacts" : "Todos los contactos",
    "Not grouped" : "No agrupado",
    "Post Office Box" : "Buzón de correo",
    "Postal Code" : "Código Postal",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Country" : "País",
    "Address" : "Dirección",
    "(new group)" : "(nuevo grupo)",
    "New contact" : "Nuevo contacto",
    "{addressbook} shared by {owner}" : "{addressbook} compartido por {owner}",
    "No contacts in file. Only VCard files are allowed." : "No hay contactos en el archivo. Solamente se permiten archivos VCard.",
    "Nickname" : "Apodo",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Federated Cloud ID" : "ID Nube Federada",
    "Home" : "Casa",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Groups" : "Grupos",
    "Birthday" : "Fecha de nacimiento",
    "Email" : "Correo electrónico",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono",
    "Mobile" : "Móvil",
    "Fax" : "Fax",
    "Fax home" : "Fax hogareño",
    "Fax work" : "Fax del trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Social Network" : "Red social",
    "Settings" : "Ajustes"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/es.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "Address book name" : "Nombre de libreta de direcciones",
    "Import" : "Importar",
    "The selected image is too big (max 1MB)" : "La imagen seleccionada es demasiada grande (máximo 1MB)",
    "No contacts in here" : "No hay contactos aquí",
    "Name" : "Nombre",
    "Organization" : "Organización",
    "Title" : "Título",
    "Add field ..." : "Añadir campo ...",
    "+ New contact" : "+ Nuevo contacto",
    "No search result for {query}" : "Sin resultados para {query}",
    "_%n contact_::_%n contacts_" : ["%n contacto","%n contactos"],
    "Post office box" : "Apartado de correos",
    "Postal code" : "Código postal",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Country" : "País",
    "Address" : "Dirección",
    "(new group)" : "(nuevo grupo)",
    "Last name" : "Apellido",
    "First name" : "Nombre",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "All contacts" : "Todos los contactos",
    "Not grouped" : "No agrupado",
    "New contact" : "Nuevo contacto",
    "{addressbook} shared by {owner}" : "{addressbook} compartido por {owner}",
    "No contacts in file. Only VCard files are allowed." : "No hay contactos en el archivo. Solamente se permiten archivos VCard.",
    "Nickname" : "Apodo",
    "Detailed name" : "Nombre",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Federated Cloud ID" : "ID Nube Federada",
    "Home" : "Casa",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Groups" : "Grupos",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de fallecimiento",
    "Email" : "Correo electrónico",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono",
    "Mobile" : "Móvil",
    "Fax" : "Fax",
    "Fax home" : "Fax hogareño",
    "Fax work" : "Fax del trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Social network" : "Redes sociales",
    "Settings" : "Ajustes"
},
"nplurals=2; plural=(n != 1);");
